@@ -79,12 +79,14 @@ def parse_args():
     undo_parser.add_argument("process_id", help="Process ID to undo")
     undo_parser.add_argument("--verbose", action="store_true", help="Verbose output")
     undo_parser.add_argument("--force", action="store_true", help="Force undo even if errors occur")
+    undo_parser.add_argument("--summary", default=None, help="Path to save a summary copy of the log")
 
     # ---------------- Redo ----------------
     redo_parser = subparsers.add_parser("redo", help="Redo a previous fylex process")
     redo_parser.add_argument("process_id", help="Process ID to redo")
     redo_parser.add_argument("--verbose", action="store_true", help="Verbose output")
     redo_parser.add_argument("--force", action="store_true", help="Force redo even if errors occur")
+    redo_parser.add_argument("--summary", default=None, help="Path to save a summary copy of the log")
 
     return parser.parse_args()
 
