@@ -651,9 +651,10 @@ def copy_with_conflict_resolution(mode: str, src: Path | str, dest: Path | str,
 
     save_as = Path(dest) / src.name
     if dest_file.exists():
-        save_as = str(Path(backup) / str(datetime.datetime.now()))
+        save_as = Path(backup) / datetime.datetime.now().isoformat()
 
     action = resolve_conflict(src, dest_file, resolve)
+
     if isinstance(action, Path):
         save_as = action
         logging.info(f"[RENAME] Renaming copy target: {src} -> {action}")
@@ -670,15 +671,30 @@ def copy_with_conflict_resolution(mode: str, src: Path | str, dest: Path | str,
             else:
                 with thread_lock:
                     state.total_memory_operated += action.stat().st_size
+                if mode == "move":
+                    if src.exists() and src.is_file():
+                        src.unlink()
+                        logging.info(f"[PROGRESS: {progress()}%] File moved and hash verified using {algo} successfully.")
+                    else:
+                        logging.info(f"[PHANTOM] File vanished before completing the operation: {src}")
+                else:
                     logging.info(f"[PROGRESS: {progress()}%] File copied and hash verified using {algo} successfully.")
+                with thread_lock:
                     state.dupe_candidates.setdefault(action.stat().st_size, []).append(get_or_update_file_hash(action, algo, chunk_size))
         else:
             with thread_lock:
                 state.total_memory_operated += action.stat().st_size
-            logging.info(f"[PROGRESS: {progress()}%] File copied using {algo} successfully.")
+            if mode == "move":
+                if src.exists() and src.is_file():
+                    src.unlink()
+                    logging.info(f"[PROGRESS: {progress()}%] File moved successfully.")
+                else:
+                    logging.info(f"[PHANTOM] File vanished before completing the operation: {src}")
+            else:
+                logging.info(f"[PROGRESS: {progress()}%] File copied successfully.")
         return True
 
-    if action:
+    if action and isinstance(action, bool):
         logging.info(f"[COPY] Copying {src} -> {dest_file}")
         if (dest_file.is_file()):
             logging.info(f"[DEPRECATE] {dest_file} is deprecated. Transferring it to: {save_as}")
@@ -696,16 +712,40 @@ def copy_with_conflict_resolution(mode: str, src: Path | str, dest: Path | str,
             else:
                 with thread_lock:
                     state.total_memory_operated += src.stat().st_size
-                logging.info(f"[PROGRESS: {progress()}%] File copied and hash verified using {algo} successfully.")
+                if mode == "move":
+                    if src.exists() and src.is_file():
+                        src.unlink()
+                        logging.info(f"[PROGRESS: {progress()}%] File moved and hash verified using {algo} successfully.")
+                    else:
+                        logging.info(f"[PHANTOM] File vanished before completing the operation: {src}")
+                else:
+                    logging.info(f"[PROGRESS: {progress()}%] File copied and hash verified using {algo} successfully.")
+                with thread_lock:
+                    state.dupe_candidates.setdefault(save_as.stat().st_size, []).append(get_or_update_file_hash(save_as, algo, chunk_size))
+
         else:
             with thread_lock:
                 state.total_memory_operated += src.stat().st_size
-            logging.info(f"[PROGRESS: {progress()}%] File copied using {algo} successfully.")
+            if mode == "move":
+                if src.exists() and src.is_file():
+                    src.unlink()
+                    logging.info(f"[PROGRESS: {progress()}%] File moved successfully.")
+                else:
+                    logging.info(f"[PHANTOM] File vanished before completing the operation: {src}")
+            else:
+                logging.info(f"[PROGRESS: {progress()}%] File copied successfully.")
         return True
     else:
         with thread_lock:
             state.total_memory_operation -= src.stat().st_size
-        logging.info(f"[SKIP] Skipping {src}, conflict resolution = {resolve}")
+        if mode == "move":
+            # Move original file to backup
+            create_dirs(src / "fylex.deprecated" / str(state.current_process), e_ok=True, dry_run=dry_run)
+            target_path = src / "fylex.deprecated" / str(state.current_process) / src.name
+            fast_move(src, target_path, algo, dry_run)
+            logging.info(f"[SKIP] Deprecating {src}, conflict resolution = {resolve}")
+        else:
+            logging.info(f"[SKIP] Skipping {src}, conflict resolution = {resolve}")
         return False
 
 
@@ -736,7 +776,7 @@ def fileops(func_name: str, src: Path | str, dest: Path | str, resolve: str = "r
             chunk_size: int = FylexConfig.DEFAULT_CHUNK_SIZE, verbose: bool = True, dry_run: bool = False, summary: Path | str = None, 
             match_regex: str = None, match_names: str = None, match_glob: str = None, exclude_regex: str = None, exclude_names: str = None, 
             exclude_glob: str = None, recursive_check: bool = False, recurse: bool = False, verify: bool = False, has_extension: bool = False, 
-            no_create: bool = False, preserve_meta: bool = True, backup: Path | str = "fylex.deprecated") -> bool:
+            no_create: bool = False, preserve_meta: bool = True, backup: Path | str = "fylex.deprecated") -> int:
     global state
     src = Path(src).resolve()
     dest = Path(dest).resolve()
@@ -824,24 +864,22 @@ def fileops(func_name: str, src: Path | str, dest: Path | str, resolve: str = "r
             resolve, verbose, preserve_meta, verify, chunk_size, trials=0, recurse=recurse
         )
 
-        if func_name == "filemove":
-            # Move original file to backup
-            create_dirs(backup, e_ok=True, dry_run=dry_run)
-            target_path = backup / file.name
-            fast_move(file, target_path, algo, dry_run)
 
     # Cleanup empty folders
     with thread_lock:
-        logging.info(f"[NOTE] Note down the process ID for future reference: {state.current_process}")
+        process_id = state.current_process
+
+    logging.info(f"[NOTE] Note down the process ID for future reference: {process_id}")
 
     if backup.exists() and not any(backup.iterdir()):
         backup.rmdir()
+        
     temp = dest / "fylex.tmp"
     if temp.exists() and not any(temp.iterdir()):
         temp.rmdir()
 
     log_copier(func_name, summary)
-    return True
+    return process_id
 
 
 def filecopy(src: Path | str, dest: Path | str, resolve: str = "rename", algo: str = FylexConfig.DEFAULT_HASH_ALGO, chunk_size: int = FylexConfig.DEFAULT_CHUNK_SIZE, 
@@ -1043,3 +1081,24 @@ def redo(p_id: str, verbose: bool = True, force: bool = False, summary: Path | s
 
     log_copier(func_name, summary)
     return True
+
+def get_commit_folders(src: str, recurse: bool):
+    src_path = Path(src)
+    if not src_path.is_dir():
+        raise ValueError(f"{src} is not a valid directory")
+    kill_folders = [src_path / "fylex.tmp", src_path / "fylex.deprecated"]
+    if recurse:
+        for content in src_path.iterdir(): 
+            if content.is_dir():
+                if content.name in ["fylex.tmp", "fylex.deprecated"]:
+                    kill_folders.append(content)
+                else:
+                    kill_folders.extend(get_commit_folders(str(content), recurse)) 
+    return kill_folders
+
+def commit(src: Path | str, force: bool = False, recurse: bool = False, dry_run: bool = False) -> bool:
+    search = get_commit_folders(src, recurse) 
+    if dry_run:
+        for folder in search:
+            logging.info(folder)
+    return True
\ No newline at end of file
